from typing import Tuple, List, Dict, Optional

from edge.webserver.sysconf.types.defs import CTRL_UICONF_PATH
from edge.services.types.service import IService
from edge.types.origin import Origin


class AboutServiceConf:
    def __init__(self, origin_about_path: str, server_about_path: str = CTRL_UICONF_PATH):
        """
        :param origin_about_path:
            /etc/edge/setupstore/admin/actions/pipeline/0/about.json
        :param server_about_path:
            /etc/edge/setupstore/about.json
        """
        self.origin_about_path = origin_about_path
        self.server_about_path = server_about_path


class IAboutService(IService):
    def get_origin(self, ts: int, lane: str = '') -> Origin:
        raise NotImplementedError

    @property
    def hw_serial(self) -> str:
        raise NotImplementedError

    @property
    def hw_vendor(self) -> str:
        raise NotImplementedError

    @property
    def hw_model(self) -> str:
        raise NotImplementedError

    @property
    def hw_info(self) -> Tuple[str, str, str]:
        return '', '', ''

    @property
    def sw_info(self) -> List[Dict]:
        raise NotImplementedError

    @property
    def sw_name(self) -> str:
        raise NotImplementedError

    @property
    def base_url(self) -> Optional[str]:
        raise NotImplementedError
